@@ -2,8 +2,8 @@ from dataclasses import dataclass
 from functools import cached_property
 
 from beet import Context
-from mecha import Mecha
-from mecha.contrib.bolt import Runtime
+from mecha import AstCommand, Mecha
+from bolt import Runtime
 
 
 @dataclass
@@ -18,5 +18,8 @@ class Integrity:
     def _runtime(self):
         return self.ctx.inject(Runtime)
 
-    def _inject_command(self, cmd: str):
-        self._runtime.commands.append(self._mc.parse(cmd, using="command"))
+    def _inject_command(self, node: AstCommand):
+        self._runtime.commands.append(node)
+
+    def _inject_raw(self, cmd: str):
+        self._inject_command(self._mc.parse(cmd, using="command"))
